/*
 * Copyright (c) 1995, 1996, 1997, 1998 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Kungliga Tekniska
 *      Hgskolan and its contributors.
 *
 * 4. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "mount_locl.h"

static const struct mntopt mopts[] = {
    MOPT_STDOPTS,
    MOPT_ASYNC,
    MOPT_SYNC,
    MOPT_UPDATE,
    MOPT_RELOAD,
    {NULL}
};

static void
usage(void)
{
    fprintf(stderr, "Usage: %s [-o options] device path\n", __progname);
    exit(1);
}

int
main(int argc, char **argv)
{
    int error;
    int ch, mntflags = 0;

    optind = 1;
#ifdef HAVE_OPTRESET
    optreset = 1;
#endif
    while ((ch = getopt(argc, argv, "o:")) != -1)
	switch (ch) {
	case 'o':
	    getmntopts(optarg, mopts, &mntflags);
	    break;
	case '?':
	default:
	    usage();
	}

    argc -= optind;
    argv += optind;

    if (argc != 2)
	usage();

    /*
     * Currently these functions are only implemented on FreeBSD.
     */

#if defined(HAVE_GETVFSBYNAME) && defined(HAVE_VFSISLOADABLE) && defined(HAVE_VFSLOAD)
    {
	struct vfsconf *vfc;
	vfc = getvfsbyname("xfs");
	/* if getvfsbyname fails the first time, then call vfsload.
	 */
	if (!vfc && vfsisloadable("xfs")) {
	    if (vfsload("xfs")) {
		err(1, "vfsload(xfs)");
	    }
	    endvfsent();
	    vfc = getvfsbyname("xfs");
	}
	if (!vfc) {
	    err(1,"xfs filesystem not available");
	}
	error = mount(vfc->vfc_index, argv[1], mntflags, argv[0]);
    }
#else
    error = mount(MOUNT_XFS, argv[1], mntflags, argv[0]);
#endif

    if (error != 0)
	err(1, "mount");

    return 0;
}
